==> DateTime-Locale-1.39.tar.gz: DateTime-Locale-1.39/share/gd-GB.pl <==
{
  am_pm_abbreviated => [
    "m",
    "f",
  ],
  available_formats => {
    Bh => "hB",
    Bhm => "h:mmB",
    Bhms => "h:mm:ssB",
    E => "ccc",
    EBhm => "E h:mmB",
    EBhms => "E h:mm:ssB",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E, d",
    Ehm => "E h:mma",
    Ehms => "E h:mm:ss\N{U+202f}a",
    Gy => "y G",
    GyMMM => "LLL y G",
    GyMMMEd => "E, d MMM y G",
    GyMMMd => "d MMM y G",
    GyMd => "d/M/y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d/M",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    "MMMMW-count-few" => "'seachdain' W MMMM",
    "MMMMW-count-one" => "'seachdain' W MMMM",
    "MMMMW-count-other" => "'seachdain' W MMMM",
    "MMMMW-count-two" => "'seachdain' W MMMM",
    MMMMd => "d'mh' MMMM",
    MMMd => "d MMM",
    MMdd => "dd/MM",
    Md => "d/M",
    d => "d",
    h => "ha",
    hm => "h:mma",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mma v",
    ms => "mm:ss",
    y => "y",
    yM => "L/y",
    yMEd => "E, d/M/y",
    yMM => "LL/y",
    yMMM => "LLL Y",
    yMMMEd => "E, d MMM y",
    yMMMM => "LLLL y",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-few" => "'seachdain' w 'dhe' Y",
    "yw-count-one" => "'seachdain' w 'dhe' Y",
    "yw-count-other" => "'seachdain' w 'dhe' Y",
    "yw-count-two" => "'seachdain' w 'dhe' Y",
  },
  code => "gd-GB",
  date_format_full => "EEEE, d'mh' MMMM y",
  date_format_long => "d'mh' MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "DiL",
    "DiM",
    "DiC",
    "Dia",
    "Dih",
    "DiS",
    "DiD",
  ],
  day_format_narrow => [
    "L",
    "M",
    "C",
    "A",
    "H",
    "S",
    "D",
  ],
  day_format_wide => [
    "DiLuain",
    "DiM\N{U+00e0}irt",
    "DiCiadain",
    "DiarDaoin",
    "DihAoine",
    "DiSathairne",
    "DiD\N{U+00f2}mhnaich",
  ],
  day_stand_alone_abbreviated => [
    "DiL",
    "DiM",
    "DiC",
    "Dia",
    "Dih",
    "DiS",
    "DiD",
  ],
  day_stand_alone_narrow => [
    "L",
    "M",
    "C",
    "A",
    "H",
    "S",
    "D",
  ],
  day_stand_alone_wide => [
    "DiLuain",
    "DiM\N{U+00e0}irt",
    "DiCiadain",
    "DiarDaoin",
    "DihAoine",
    "DiSathairne",
    "DiD\N{U+00f2}mhnaich",
  ],
  era_abbreviated => [
    "RC",
    "AD",
  ],
  era_narrow => [
    "R",
    "A",
  ],
  era_wide => [
    "Ro Chr\N{U+00ec}osta",
    "An d\N{U+00e8}idh Chr\N{U+00ec}osta",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %d %b %Y %T %Z",
  glibc_date_format => "%d/%m/%y",
  glibc_datetime_format => "%a %d %b %Y %T",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%r",
  language => "Scottish Gaelic",
  month_format_abbreviated => [
    "Faoi",
    "Gearr",
    "M\N{U+00e0}rt",
    "Gibl",
    "C\N{U+00e8}it",
    "\N{U+00d2}gmh",
    "Iuch",
    "L\N{U+00f9}na",
    "Sult",
    "D\N{U+00e0}mh",
    "Samh",
    "D\N{U+00f9}bh",
  ],
  month_format_narrow => [
    "F",
    "G",
    "M",
    "G",
    "C",
    "\N{U+00d2}",
    "I",
    "L",
    "S",
    "D",
    "S",
    "D",
  ],
  month_format_wide => [
    "dhen Fhaoilleach",
    "dhen Ghearran",
    "dhen Mh\N{U+00e0}rt",
    "dhen Ghiblean",
    "dhen Ch\N{U+00e8}itean",
    "dhen \N{U+00d2}gmhios",
    "dhen Iuchar",
    "dhen L\N{U+00f9}nastal",
    "dhen t-Sultain",
    "dhen D\N{U+00e0}mhair",
    "dhen t-Samhain",
    "dhen D\N{U+00f9}bhlachd",
  ],
  month_stand_alone_abbreviated => [
    "Faoi",
    "Gearr",
    "M\N{U+00e0}rt",
    "Gibl",
    "C\N{U+00e8}it",
    "\N{U+00d2}gmh",
    "Iuch",
    "L\N{U+00f9}na",
    "Sult",
    "D\N{U+00e0}mh",
    "Samh",
    "D\N{U+00f9}bh",
  ],
  month_stand_alone_narrow => [
    "F",
    "G",
    "M",
    "G",
    "C",
    "\N{U+00d2}",
    "I",
    "L",
    "S",
    "D",
    "S",
    "D",
  ],
  month_stand_alone_wide => [
    "Am Faoilleach",
    "An Gearran",
    "Am M\N{U+00e0}rt",
    "An Giblean",
    "An C\N{U+00e8}itean",
    "An t-\N{U+00d2}gmhios",
    "An t-Iuchar",
    "An L\N{U+00f9}nastal",
    "An t-Sultain",
    "An D\N{U+00e0}mhair",
    "An t-Samhain",
    "An D\N{U+00f9}bhlachd",
  ],
  name => "Scottish Gaelic United Kingdom",
  native_language => "G\N{U+00e0}idhlig",
  native_name => "G\N{U+00e0}idhlig An R\N{U+00ec}oghachd Aonaichte",
  native_script => undef,
  native_territory => "An R\N{U+00ec}oghachd Aonaichte",
  native_variant => undef,
  quarter_format_abbreviated => [
    "C1",
    "C2",
    "C3",
    "C4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1d chairteal",
    "2na cairteal",
    "3s cairteal",
    "4mh cairteal",
  ],
  quarter_stand_alone_abbreviated => [
    "C1",
    "C2",
    "C3",
    "C4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1d chairteal",
    "2na cairteal",
    "3s cairteal",
    "4mh cairteal",
  ],
  script => undef,
  territory => "United Kingdom",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 43,
}

==> DateTime-Locale-1.41.tar.gz: DateTime-Locale-1.41/share/gd-GB.pl <==
{
  am_pm_abbreviated => [
    "m",
    "f",
  ],
  available_formats => {
    Bh => "hB",
    Bhm => "h:mmB",
    Bhms => "h:mm:ssB",
    E => "ccc",
    EBhm => "E h:mmB",
    EBhms => "E h:mm:ssB",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E, d",
    Ehm => "E h:mma",
    Ehms => "E h:mm:ss\N{U+202f}a",
    Gy => "y G",
    GyMMM => "LLL y G",
    GyMMMEd => "E, d'mh' MMM y G",
    GyMMMd => "d'mh' MMM y G",
    GyMd => "d/M/y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d/M",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    "MMMMW-count-few" => "'seachdain' W MMMM",
    "MMMMW-count-one" => "'seachdain' W MMMM",
    "MMMMW-count-other" => "'seachdain' W MMMM",
    "MMMMW-count-two" => "'seachdain' W MMMM",
    MMMMd => "d'mh' MMMM",
    MMMd => "d MMM",
    MMdd => "dd/MM",
    Md => "d/M",
    d => "d",
    h => "ha",
    hm => "h:mma",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mma v",
    ms => "mm:ss",
    y => "y",
    yM => "L/y",
    yMEd => "E, d/M/y",
    yMM => "LL/y",
    yMMM => "LLL Y",
    yMMMEd => "E, d'mh' MMM y",
    yMMMM => "LLLL y",
    yMMMd => "d'mh' MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-few" => "'seachdain' w 'dhe' Y",
    "yw-count-one" => "'seachdain' w 'dhe' Y",
    "yw-count-other" => "'seachdain' w 'dhe' Y",
    "yw-count-two" => "'seachdain' w 'dhe' Y",
  },
  code => "gd-GB",
  date_format_full => "EEEE, d'mh' MMMM y",
  date_format_long => "d'mh' MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "DiL",
    "DiM",
    "DiC",
    "Dia",
    "Dih",
    "DiS",
    "DiD",
  ],
  day_format_narrow => [
    "L",
    "M",
    "C",
    "A",
    "H",
    "S",
    "D",
  ],
  day_format_wide => [
    "DiLuain",
    "DiM\N{U+00e0}irt",
    "DiCiadain",
    "DiarDaoin",
    "DihAoine",
    "DiSathairne",
    "DiD\N{U+00f2}mhnaich",
  ],
  day_stand_alone_abbreviated => [
    "DiL",
    "DiM",
    "DiC",
    "Dia",
    "Dih",
    "DiS",
    "DiD",
  ],
  day_stand_alone_narrow => [
    "L",
    "M",
    "C",
    "A",
    "H",
    "S",
    "D",
  ],
  day_stand_alone_wide => [
    "DiLuain",
    "DiM\N{U+00e0}irt",
    "DiCiadain",
    "DiarDaoin",
    "DihAoine",
    "DiSathairne",
    "DiD\N{U+00f2}mhnaich",
  ],
  era_abbreviated => [
    "RC",
    "AD",
  ],
  era_narrow => [
    "R",
    "A",
  ],
  era_wide => [
    "Ro Chr\N{U+00ec}osta",
    "An d\N{U+00e8}idh Chr\N{U+00ec}osta",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %d %b %Y %T %Z",
  glibc_date_format => "%d/%m/%y",
  glibc_datetime_format => "%a %d %b %Y %T",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%r",
  language => "Scottish Gaelic",
  month_format_abbreviated => [
    "Faoi",
    "Gearr",
    "M\N{U+00e0}rt",
    "Gibl",
    "C\N{U+00e8}it",
    "\N{U+00d2}gmh",
    "Iuch",
    "L\N{U+00f9}na",
    "Sult",
    "D\N{U+00e0}mh",
    "Samh",
    "D\N{U+00f9}bh",
  ],
  month_format_narrow => [
    "F",
    "G",
    "M",
    "G",
    "C",
    "\N{U+00d2}",
    "I",
    "L",
    "S",
    "D",
    "S",
    "D",
  ],
  month_format_wide => [
    "dhen Fhaoilleach",
    "dhen Ghearran",
    "dhen Mh\N{U+00e0}rt",
    "dhen Ghiblean",
    "dhen Ch\N{U+00e8}itean",
    "dhen \N{U+00d2}gmhios",
    "dhen Iuchar",
    "dhen L\N{U+00f9}nastal",
    "dhen t-Sultain",
    "dhen D\N{U+00e0}mhair",
    "dhen t-Samhain",
    "dhen D\N{U+00f9}bhlachd",
  ],
  month_stand_alone_abbreviated => [
    "Faoi",
    "Gearr",
    "M\N{U+00e0}rt",
    "Gibl",
    "C\N{U+00e8}it",
    "\N{U+00d2}gmh",
    "Iuch",
    "L\N{U+00f9}na",
    "Sult",
    "D\N{U+00e0}mh",
    "Samh",
    "D\N{U+00f9}bh",
  ],
  month_stand_alone_narrow => [
    "F",
    "G",
    "M",
    "G",
    "C",
    "\N{U+00d2}",
    "I",
    "L",
    "S",
    "D",
    "S",
    "D",
  ],
  month_stand_alone_wide => [
    "Am Faoilleach",
    "An Gearran",
    "Am M\N{U+00e0}rt",
    "An Giblean",
    "An C\N{U+00e8}itean",
    "An t-\N{U+00d2}gmhios",
    "An t-Iuchar",
    "An L\N{U+00f9}nastal",
    "An t-Sultain",
    "An D\N{U+00e0}mhair",
    "An t-Samhain",
    "An D\N{U+00f9}bhlachd",
  ],
  name => "Scottish Gaelic United Kingdom",
  native_language => "G\N{U+00e0}idhlig",
  native_name => "G\N{U+00e0}idhlig An R\N{U+00ec}oghachd Aonaichte",
  native_script => undef,
  native_territory => "An R\N{U+00ec}oghachd Aonaichte",
  native_variant => undef,
  quarter_format_abbreviated => [
    "C1",
    "C2",
    "C3",
    "C4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1d chairteal",
    "2na cairteal",
    "3s cairteal",
    "4mh cairteal",
  ],
  quarter_stand_alone_abbreviated => [
    "C1",
    "C2",
    "C3",
    "C4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1d chairteal",
    "2na cairteal",
    "3s cairteal",
    "4mh cairteal",
  ],
  script => undef,
  territory => "United Kingdom",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => "44.1",
}
